#!/bin/bash

# ***************************************************************************
# *                         WARRANTY DISCLAIMER
# ***************************************************************************
# * THE SAMPLE SCRIPT IS BEING PROVIDED TO YOU "AS IS".  DELL DISCLAIMS ANY
# * AND ALL WARRANTIES, EXPRESS, IMPLIED OR STATUTORY, WITH RESPECT TO THE
# * SAMPLE SCRIPT, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND ANY WARRANTY
# * OF NON-INFRINGEMENT. YOU WILL USE THE SAMPLE SCRIPT AT YOUR OWN RISK.
# * DELL SHALL NOT BE LIABLE TO YOU FOR ANY DIRECT OR INDIRECT DAMAGES
# * INCURRED IN USING THE SAMPLE SCRIPT. IN NO EVENT SHALL DELL OR ITS
# * SUPPLIERS BE RESPONSIBLE FOR ANY DIRECT OR INDIRECT DAMAGES WHATSOEVER
# * (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS OF PROFITS, LOSS OF USE,
# * LOSS OF DATA, BUSINESS INTERRUPTION, OR OTHER PECUNIARY LOSS, NOR FOR
# * PUNITIVE, INCIDENTAL, CONSEQUENTIAL, OR SPECIAL DAMAGES OF ANY KIND,
# * UNDER ANY PART OF THIS AGREEMENT, EVEN IF ADVISED OR AWARE OF THE
# * POSSIBILITY OF SUCH DAMAGES).
# ***************************************************************************

# ***************************************************************************
# * Script Name: syscap.sh
# *
# * Purpose:
# *   This script captures system BIOS and BMC settings to a file.
# *
# * Layout: 
# *   This script is divided into the following sections for ease of use and
# *   extensibility:
# *     Section 1: Set Paths for Deployment Toolkit Tools and Scripts
# *     Section 2: Ask User's Input, Input Verification, and Code Execution
# *
# * Tools Used: 
# *   syscfg to capture the system settings
# *
# * External Dependencies
# *   DT_TOOLS, DT_SYSTEMS set by tkenvset.sh let task scripts
# *   know where they can find Toolkit Tools and Configuration scripts.
# *   DT_PLATFORM is set by tkenvset.sh using Platform Discovery.
# *
# * Input Parameters
# *	  $1 This is the filename to capture the Settings into.
# *
# * !!! WARNING !!!
# * If the file into which information needs to be captured exists it will be 
# * deleted.
# *
# ***************************************************************************

# Print usage if script is not called with correct number of arguments
noarg ()
{
        echo "usage: syscap <filename>"
	echo Filename is the name of the file to capture the Settings into.
        exit 2
}

# ***************************************************************************
# * Function to display the outcome (Success or Failure and Error Handling)
# * Expects $? as an argument to display the Return/Error Code.
# ***************************************************************************
toolfail ()
{
	echo syscfg failed with error code $1.
	$DT_SCRIPTS/errhndl.sh $0 32
	# Exit the script if Return Value is 2
	if [ $? -eq 2 ]; then
		echo "Exiting."
		exit
	fi
}

# ***************************************************************************
# * Section 1: Set Paths for Deployment Toolkit Tools and Scripts
# ***************************************************************************
# check for proper usage of the script
if [ -z $1 ]; then
        noarg
fi

if [ -z $DT_TOOLS ]; then
	. tkenvset.sh
fi

# #############################################################################
#                          USER MODIFICATION REQUIRED
# Below are the user defined variables that this script uses.
# In a full deployment, these variables should be customized to fit the 
# user's needs.
# #############################################################################
[ -z "$DT_SYS_CAPFILE" ] && DT_SYS_CAPFILE=$DT_SYSTEMS/$DT_PLATFORM/syscfg.ini

# ***************************************************************************
# * Section 2: Ask User's Input, Input Verification, and Code Execution
# ***************************************************************************
[ ! -z "$1" ] && DT_SYS_CAPFILE=$1

if [ -e $DT_SYS_CAPFILE ]; then
	rm -f $DT_SYS_CAPFILE
fi

$DT_TOOLS/syscfg -o $DT_SYS_CAPFILE
retval=$?
if [ $retval -ne 0 ]; then
	toolfail $retval
fi

echo "System information captured to $DT_SYS_CAPFILE"
